@@ -14,7 +14,7 @@ from openapi_client.models import (
     OrmHyperparameter,
     ResponseExperimentInfo,
     ResponseExperimentListResponse,
-    ResponseFileMetadata,
+    StorageFile,
     ResponseGitHubCodeRef,
 )
 from openapi_client.models.orm_execution_environment import OrmExecutionEnvironment
@@ -366,7 +366,7 @@ def list_experiment_output_files(
     recursive: bool = True,
     worker_number: int = 0,
     **kwargs,
-) -> List[ResponseFileMetadata]:
+) -> List[StorageFile]:
     """List experiment output files in the default organization/project. If you
     want to override the default organization/project, then pass
     `organization_name` or `project_name` as `**kwargs`.
@@ -460,7 +460,6 @@ def download_experiment_output_files(
             source_path="",
             dest_volume_id=None,
             dest_path=dest_path,
-            recursive=True,
         )
     if experiment.is_distributed:
         worker_replicas = experiment.distributed_spec.pytorch_spec.worker_replicas
@@ -476,7 +475,6 @@ def download_experiment_output_files(
                     source_path="",
                     dest_volume_id=None,
                     dest_path=dest_path,
-                    recursive=True,
                 )
     else:
         for volume_mount in experiment.volume_mounts.mounts:
@@ -486,7 +484,6 @@ def download_experiment_output_files(
                     source_path="",
                     dest_volume_id=None,
                     dest_path=dest_path,
-                    recursive=True,
                 )
 
     logger.info("No output volume mounted")
