@@ -1,5 +1,4 @@
 import os
-import tempfile
 from typing import Dict, List, Optional
 
 from openapi_client import ProtoVolumeMountRequestSourceModelVolume
@@ -10,7 +9,7 @@ from openapi_client.models import (
     ProtoVolumeMountRequestSourceCode,
     ProtoVolumeMountRequestSourceDataset,
     ProtoVolumeMountRequestSourceDatasetVersion,
-    ResponseFileMetadata,
+    StorageFile,
     VolumeFileCopyAPIInput,
     VolumeFileCreateAPIInput,
 )
@@ -19,6 +18,7 @@ from vessl.organization import _get_organization_name
 from vessl.project import _get_project
 from vessl.util.constant import (
     DATASET_VERSION_HASH_LATEST,
+    EXPERIMENT_WORKING_DIR,
     MOUNT_PATH_EMPTY_DIR,
     MOUNT_TYPE_ARCHIVE_FILE,
     MOUNT_TYPE_CODE,
@@ -27,6 +27,7 @@ from vessl.util.constant import (
     MOUNT_TYPE_EMPTY_DIR,
     MOUNT_TYPE_MODEL_VOLUME,
     MOUNT_TYPE_OUTPUT,
+    TEMP_DIR,
 )
 from vessl.util.downloader import Downloader
 from vessl.util.exception import (
@@ -37,11 +38,11 @@ from vessl.util.exception import (
 )
 from vessl.util.git_local import get_git_diff_path, get_git_ref, get_git_repo
 from vessl.util.random import random_string
+from vessl.util.tar import Tar
 from vessl.util.uploader import Uploader
-from vessl.util.zipper import Zipper
 
 
-def read_volume_file(volume_id: int, path: str) -> ResponseFileMetadata:
+def read_volume_file(volume_id: int, path: str) -> StorageFile:
     """Read a file in the volume.
 
     Args:
@@ -64,7 +65,7 @@ def list_volume_files(
     need_download_url: bool = False,
     path: str = "",
     recursive: bool = False,
-) -> List[ResponseFileMetadata]:
+) -> List[StorageFile]:
     """List files in the volume.
 
     Args:
@@ -91,7 +92,7 @@ def list_volume_files(
     return sorted(result, key=lambda x: x.path)
 
 
-def create_volume_file(volume_id: int, is_dir: bool, path: str) -> ResponseFileMetadata:
+def create_volume_file(volume_id: int, is_dir: bool, path: str) -> StorageFile:
     """Create file in the volume.
 
     Args:
@@ -115,20 +116,18 @@ def create_volume_file(volume_id: int, is_dir: bool, path: str) -> ResponseFileM
             path=path,
         ),
     )
-    assert isinstance(result, ResponseFileMetadata)
+    assert isinstance(result, StorageFile)
     return result
 
 
 def delete_volume_file(
-    volume_id: int, path: str, recursive: bool = False
-) -> List[ResponseFileMetadata]:
+    volume_id: int, path: str,
+):
     """Delete file in the volume.
 
     Args:
         volume_id(int): Volume ID.
         path(str): Path within the volume.
-        recursive(bool): True if list files recursively, False otherwise.
-            Defaults to False.
 
     Example:
         ```python
@@ -138,12 +137,12 @@ def delete_volume_file(
         )
         ```
     """
-    return vessl_api.volume_file_delete_api(
-        volume_id=volume_id, path=path, recursive=recursive
-    ).deleted_files
+    vessl_api.volume_file_delete_api(
+        volume_id=volume_id, path=path,
+    )
 
 
-def upload_volume_file(volume_id: int, path: str) -> ResponseFileMetadata:
+def upload_volume_file(volume_id: int, path: str) -> StorageFile:
     """Upload file in the volume.
 
     Args:
@@ -166,9 +165,8 @@ def copy_volume_file(
     source_path: str,
     dest_volume_id: Optional[int],
     dest_path: str,
-    recursive: bool = False,  # Only used for remote to remote
     quiet: bool = False,
-) -> Optional[List[ResponseFileMetadata]]:
+) -> Optional[List[StorageFile]]:
     """Copy file either from local to remote, remote to local, or remote to
     remote.
 
@@ -181,8 +179,6 @@ def copy_volume_file(
             specified, destination is assumed to be local.
         dest_path(str): If dest_volume_id is empty, local destination path.
             Otherwise, remote destination path.
-        recursive(bool): True if list files recursively, False otherwise.
-            Only used for remote to remote copy. Defaults to False.
         quiet(bool): True if the muted output, False otherwise. Defaults to
             False.
 
@@ -213,13 +209,13 @@ def copy_volume_file(
 
     if source_volume_id and dest_volume_id:
         return _copy_volume_file_remote_to_remote(
-            source_volume_id, source_path, dest_volume_id, dest_path, recursive
+            source_volume_id, source_path, dest_volume_id, dest_path,
         )
 
 
 def _copy_volume_file_local_to_remote(
     source_path: str, dest_volume_id: int, dest_path: str
-) -> List[ResponseFileMetadata]:
+) -> List[StorageFile]:
     """Copy local to remote
 
     Behavior works like linux cp command
@@ -282,38 +278,38 @@ def _copy_volume_file_remote_to_local(
       - `dest_path` exists: copy `source_path` as subdirectory of `dest_path`
     """
 
-    source_file = read_volume_file(source_volume_id, source_path)
+    try:
+        source_file = read_volume_file(source_volume_id, source_path)
+    except VesslApiException:
+        if os.path.isfile(dest_path):
+            # Case where `source_path` is a directory and `dest_path` is an
+            # existing filename
+            raise InvalidVolumeFileError(
+                f"Destination path is not a directory: {dest_path}."
+            )
 
-    if not source_file.is_dir:
-        file_name = os.path.basename(source_file.path)
-        if os.path.isdir(dest_path):
-            dest_path = os.path.join(dest_path, file_name)
-
-            if os.path.isdir(dest_path):
-                # Case where `source_path` is "a.txt", `dest_path` is "dir/", and
-                # "dir/a.txt/" exists as a directory
-                raise InvalidParamsError(
-                    f"Cannot overwrite directory {dest_path} with non-directory {file_name}."
-                )
-
-        Downloader.download(source_path, dest_path, source_file, quiet=quiet)
-        return
-
-    if os.path.isfile(dest_path):
-        # Case where `source_path` is a directory and `dest_path` is an
-        # existing filename
-        raise InvalidVolumeFileError(
-            f"Destination path is not a directory: {dest_path}."
+        files = list_volume_files(
+            volume_id=source_volume_id,
+            need_download_url=True,
+            path=source_path,
+            recursive=True,
         )
 
-    files = list_volume_files(
-        volume_id=source_volume_id,
-        need_download_url=True,
-        path=source_path,
-        recursive=True,
-    )
+        Downloader.download(source_path, dest_path, *files, quiet=quiet)
+        return
 
-    Downloader.download(source_path, dest_path, *files, quiet=quiet)
+    file_name = os.path.basename(source_file.path)
+    if os.path.isdir(dest_path):
+        dest_path = os.path.join(dest_path, file_name)
+
+        if os.path.isdir(dest_path):
+            # Case where `source_path` is "a.txt", `dest_path` is "dir/", and
+            # "dir/a.txt/" exists as a directory
+            raise InvalidParamsError(
+                f"Cannot overwrite directory {dest_path} with non-directory {file_name}."
+            )
+
+    Downloader.download(source_path, dest_path, source_file, quiet=quiet)
 
 
 def _copy_volume_file_remote_to_remote(
@@ -321,22 +317,20 @@ def _copy_volume_file_remote_to_remote(
     source_path: str,
     dest_volume_id: int,
     dest_path: str,
-    recursive: bool,
 ) -> None:
     if source_volume_id != dest_volume_id:
         raise InvalidVolumeFileError("Files can only be copied within the same volume.")
 
-    files = vessl_api.volume_file_copy_api(
+    vessl_api.volume_file_copy_api(
         volume_id=source_volume_id,
         volume_file_copy_api_input=VolumeFileCopyAPIInput(
             dest_path=dest_path,
-            recursive=recursive,
             source_dataset_version="latest",
             source_path=source_path,
         ),
-    ).copied_files
+    )
 
-    print(f"Successfully copied {len(files)} out of {len(files)} file(s).")
+    print(f"Successfully copied.")
 
 
 def _print_volume_mount_requests_tree(
@@ -529,30 +523,28 @@ def _configure_volume_mount_request_local_files(
     for local_file in local_files:
         if ":" in local_file:
             local_path, remote_path = local_file.split(":")
-            if not os.path.isabs(remote_path):
-                remote_path = os.path.join("/home/vessl", remote_path)
+            if not remote_path.startswith("/"):
+                remote_path = f"{EXPERIMENT_WORKING_DIR}{remote_path}"
         else:
             local_path = local_file
-            remote_path = "/home/vessl/local"
+            remote_path = f"{EXPERIMENT_WORKING_DIR}local"
 
         cwd = os.path.abspath(local_path)
-        zip_path = os.path.abspath(
-            os.path.join(tempfile.gettempdir(), f"{project.name}_{random_string()}.zip")
+        gzip_file_full_path = os.path.abspath(
+            os.path.join(TEMP_DIR, f"{project.name}_{random_string()}.tar.gz")
         )
 
         print(f"Uploading... [{cwd} -> {remote_path}]")
-        zipper = Zipper(zip_path, "w")
-        zipper.zip(cwd)
-        zipper.close()
+        Tar.gzip(gzip_file_full_path, cwd)
 
         uploaded = Uploader.upload(
-            local_path=zipper.filename,
+            local_path=gzip_file_full_path,
             volume_id=project.volume_id,
-            remote_path=os.path.basename(zipper.filename),
+            remote_path=os.path.basename(gzip_file_full_path),
         )
         print(f"Upload completed successfully.")
+        os.remove(gzip_file_full_path)
 
-        os.remove(zipper.filename)
         volume_mount_requests.append(
             _configure_volume_mount_request_archive_file(
                 archive_file_mount=f"{remote_path}:{uploaded.path}"
@@ -576,9 +568,9 @@ def _configure_volume_mount_request_local_git(
     volume_mount_requests: List[ProtoVolumeMountRequest] = []
     used_mount_paths = set()
     for repo in project.project_repositories:
-        mount_path = f"/home/vessl/{repo.git_repo}"
+        mount_path = f"{EXPERIMENT_WORKING_DIR}{repo.git_repo}"
         if mount_path in used_mount_paths:
-            mount_path = f"/home/vessl/{repo.git_repo}-{repo.git_owner}"
+            mount_path = f"{EXPERIMENT_WORKING_DIR}{repo.git_repo}-{repo.git_owner}"
 
         git_mount_info = f"github/{repo.git_owner}/{repo.git_repo}/latest"
         git_diff_path = None
