@@ -1,10 +1,12 @@
 import os
+import subprocess
 import urllib.parse
 from datetime import datetime
 from pathlib import Path
 from typing import Any, Dict, List
 
 import click
+import humanfriendly
 import inquirer
 import paramiko
 
@@ -24,9 +26,16 @@ from vessl.kernel_resource_spec import (
     read_kernel_resource_spec,
 )
 from vessl.organization import _get_organization_name
+from vessl.util.tar import Tar
 from vessl.util.common import parse_time_to_ago
 from vessl.util.config import VesslConfigLoader
-from vessl.util.constant import SSH_CONFIG_FORMAT, SSH_CONFIG_PATH, TEMP_DIR
+from vessl.util.constant import (
+    SSH_CONFIG_FORMAT,
+    SSH_CONFIG_PATH,
+    TEMP_DIR,
+    WORKSPACE_BACKUP_MAX_SIZE,
+    WORKSPACE_BACKUP_MAX_SIZE_FORMATTED,
+)
 from vessl.util.exception import InvalidWorkspaceError, VesslException
 from vessl.util.random import random_string
 from vessl.util.zipper import Zipper
@@ -322,26 +331,43 @@ def backup_workspace() -> None:
 
     workspace = read_workspace(workspace_id)
 
-    filename = f'workspace-backup-{datetime.utcnow().strftime("%Y%m%d%H%M%S")}-{random_string()}.zip'
-    full_path = os.path.join(TEMP_DIR, filename)
+    filename = f'workspace-backup-{datetime.utcnow().strftime("%Y%m%d%H%M%S")}-{random_string()}.tar.gz'
+    gzip_file_full_path = os.path.join(TEMP_DIR, filename)
     home_dir = str(Path.home())
-    zipper = Zipper(full_path, "w")
-    zipper.zipdir(home_dir, include_dotfiles=True)
-    zipper.close()
-    size = zipper.size()
-    print(f"Backup file size: {size}")
-    if size > 15 * 1024 * 1024 * 1024:
-        zipper.remove()
-        raise VesslException(f"{home_dir} is too large to backup.")
 
+    home_dir_size = -1
+    try:
+        # use -k option because there is no -b option on UNIX du
+        home_dir_size_in_kilobytes = int(subprocess.check_output(['du', '-sk', home_dir]).decode().split('\t')[0])
+        home_dir_size = home_dir_size_in_kilobytes * 1024
+    except Exception:
+        pass
+
+    if home_dir_size > WORKSPACE_BACKUP_MAX_SIZE:
+        formatted_size = humanfriendly.format_size(home_dir_size, binary=True)
+        raise VesslException(
+            f"Failed: The size of {home_dir} should be less than {WORKSPACE_BACKUP_MAX_SIZE_FORMATTED} to backup. "
+            f"Current size is {formatted_size}.",
+        )
+
+    print("Creating a backup file...")
+    size = Tar.gzip(gzip_file_full_path, home_dir, exclude_paths=[".vessl"])
+    if size > WORKSPACE_BACKUP_MAX_SIZE:
+        formatted_size = humanfriendly.format_size(size, binary=True)
+        raise VesslException(
+            f"Failed: The size of {home_dir} should be less than {WORKSPACE_BACKUP_MAX_SIZE_FORMATTED} to backup. "
+            f"Current size is {formatted_size}.",
+        )
+
+    print(f"Backup file size: {humanfriendly.format_size(size, binary=True)}")
     print("Uploading the backup file...")
     copy_volume_file(
         source_volume_id=None,
-        source_path=full_path,
+        source_path=gzip_file_full_path,
         dest_volume_id=workspace.backup_volume_id,
         dest_path=filename,
     )
-    zipper.remove()
+    os.remove(gzip_file_full_path)
 
     vessl_api.cli_workspace_backup_create_api(
         workspace_id=workspace_id,
@@ -351,74 +377,61 @@ def backup_workspace() -> None:
     )
 
 
-def restore_workspace(workspace_id: int = None) -> None:
+def restore_workspace() -> None:
     """Restore the home directory from the previous backup. This command should
     be called inside a workspace.
 
-    Args:
-        workspace_id(int): Workspace ID.
-
     Example:
         ```python
         vessl.restore_workspace()
         ```
     """
+    workspace_id = VesslConfigLoader().workspace
     if workspace_id is None:
-        workspace_id = VesslConfigLoader().workspace
-        if workspace_id is None:
-            raise InvalidWorkspaceError("Can only be called within a workspace.")
+        raise InvalidWorkspaceError("Can only be called within a workspace.")
 
-        workspace_list = list_workspaces(mine=True)
-        backup_workspaces = [w for w in workspace_list if w.last_backup is not None]
-        if len(backup_workspaces) == 0:
-            raise click.ClickException("Available workspace backup not found.")
+    workspace = read_workspace(workspace_id=workspace_id)
+    if workspace.last_backup is None:
+        raise click.ClickException("This workspace does not have any backup.")
 
-        workspace = inquirer.prompt(
-            [
-                inquirer.List(
-                    "question",
-                    message="Select workspace",
-                    choices=[
-                        (
-                            f"{w.name} (backup created "
-                            f"{parse_time_to_ago(w.last_backup.created_dt)})",
-                            w,
-                        )
-                        for w in backup_workspaces
-                    ],
-                )
-            ],
-            raise_keyboard_interrupt=True,
-        ).get("question")
-    else:
-        workspace = read_workspace(workspace_id=workspace_id)
-        if workspace.last_backup is None:
-            raise click.ClickException("This workspace does not have any backup.")
-
-    dest_path = os.path.join(TEMP_DIR, "workspace-backup.zip")
-    print("Downloading the backup file...")
-    copy_volume_file(
-        source_volume_id=workspace.backup_volume_id,
-        source_path=workspace.last_backup.filename,
-        dest_volume_id=None,
-        dest_path=dest_path,
-    )
-
-    zipper = Zipper(dest_path, "r")
-    size = zipper.size()
-    print(f"Backup file size: {size}")
-    extract_path = str(Path.home())
-    if size > 15 * 1024 * 1024 * 1024:
-        extract_path = os.path.join(TEMP_DIR, "workspace-backup")
-    print("Extracting...")
-    zipper.extractall(extract_path)
-    if size > 15 * 1024 * 1024 * 1024:
-        print(
-            f"Restored to {extract_path} "
-            f"since the size of the backup file is larger than 15Gi."
+    if workspace.last_backup.filename.endswith(".zip"):
+        dest_path = os.path.join(TEMP_DIR, "workspace-backup.zip")
+        print("Downloading the backup file...")
+        copy_volume_file(
+            source_volume_id=workspace.backup_volume_id,
+            source_path=workspace.last_backup.filename,
+            dest_volume_id=None,
+            dest_path=dest_path,
         )
-    zipper.close()
-    zipper.remove()
+
+        zipper = Zipper(dest_path, "r")
+        size = zipper.size()
+        print(f"Backup file size: {size}")
+        extract_path = str(Path.home())
+        if size > WORKSPACE_BACKUP_MAX_SIZE:
+            extract_path = os.path.join(TEMP_DIR, "workspace-backup")
+        print("Extracting...")
+        zipper.extractall(extract_path)
+        if size > WORKSPACE_BACKUP_MAX_SIZE:
+            print(
+                f"Restored to {extract_path} "
+                f"since the size of the backup file is larger than {WORKSPACE_BACKUP_MAX_SIZE_FORMATTED}. "
+            )
+        zipper.close()
+        zipper.remove()
+    else:
+        gzip_file_full_path = os.path.join(TEMP_DIR, "workspace-backup.tar.gz")
+        print("Downloading the backup file...")
+        copy_volume_file(
+            source_volume_id=workspace.backup_volume_id,
+            source_path=workspace.last_backup.filename,
+            dest_volume_id=None,
+            dest_path=gzip_file_full_path,
+        )
+
+        print("Extracting...")
+        Tar.extract(gzip_file_full_path, str(Path.home()))
+        os.remove(gzip_file_full_path)
 
 
 def connect_workspace_ssh(private_key_path: str) -> None:
@@ -459,7 +472,7 @@ def connect_workspace_ssh(private_key_path: str) -> None:
     ssh_private_key_option = f" -i {private_key_path}" if private_key_path else ""
     os.system(
         f"ssh -p {ssh_endpoint.port}{ssh_private_key_option} "
-        f"vessl@{ssh_endpoint.hostname}"
+        f"root@{ssh_endpoint.hostname}"
     )
 
 
